(TeX-add-style-hook
 "library"
 (lambda ()
   (LaTeX-add-bibitems
    "ImKo16"
    "BeMc02"
    "PuTi18"
    "moulton86"
    "satterthwaite46"))
 :bibtex)

